==========================
Frequently Asked Questions
==========================

Well I'm lying, no one asked any of these question and I don't even known if there's a single person that is going to read this documentation or use my program but i think writing documentation is good practice. `(Hire me senpai >_<) <mailto:sydiepus@gmail.com?subject=Company%20is%20interested%20in%20you%21&body=Hired%20UwU>`_

Why the name Manrododex ?
=========================

Well it's a combination of three different *words* : Man/rodo/dex

1. **Man**: for Manga.
2. **rodo**: for the load part of download in japanese `ダウンロード <https://jisho.org/word/%E3%83%80%E3%82%A6%E3%83%B3%E3%83%AD%E3%83%BC%E3%83%89>`_ which is ロード in katakana or rōdo in romaji.
3. **dex**: for the dex in `MangaDex <https://mangadex.org>`_

Joining all these information we get : Manga daunrodo dex, which makes no sense.

What is a UUID ?
================

From wikipedia UUID: Universally unique identifier, A universally unique identifier is a 128-bit label used for information in computer systems. The term globally unique identifier is also used. When generated according to the standard methods, UUIDs are, for practical purposes, unique.

| Putting it simply it's a text made of letters and numbers separated by `-` and is unique.
| An example would be : `17876b69-42a2-4228-aeda-f8e14f4f94f4`

How does this relate to MangaDex ?
----------------------------------

Well MangaDex uses UUIDs as a way to uniquely identify mangas, and is used by the program to download the manga that you want.

What are you talking about ? I never saw that thing on MangaDex ?
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

| Maybe you don't pay enough attention to links in your browser.
| It's right there:

.. figure:: ../_images/uuid_in_the_wild.png

What's the default title ?
==========================

| It's the title writen in white, big enough for you not to miss it.
| Here:

.. figure:: ../_images/default_title.png

What's the alt title ?
======================

| alt title or Alternative Title is the non default title usually in a different language than the default one.
| MangaDex write the english alt title for the manga under the default one like this:

.. figure:: ../_images/alt_title.png

| Other Alternative Titles are writen to the left of the chapters like this:

.. figure:: ../_images/alt_titles.png